def get_or_create(session, model, **kw):
    obj = session.query(model).filter_by(**kw).first()
    if obj:
        return obj
    else:
        obj = model(**kw)
        session.add(obj)
        session.flush()
        return obj


import os

from pyramid.view import view_config
from pyramid.response import Response


_here = os.path.dirname(__file__)
_robots = open(os.path.join(_here, '../static', 'robots.txt')).read()
_robots_response = Response(content_type='text/plain', body=_robots)
_favicon = open(os.path.join(_here, '../static', 'favicon.ico')).read()
_favicon_response = Response(content_type='image/x-icon', body=_favicon)

@view_config(name='robots.txt')
def robotstxt_view(request):
    return _robots_response


@view_config(name='favicon.ico')
def favicon_view(request):
    return _favicon_response


@view_config(context='pyramid.exceptions.NotFound', renderer='404.html')
@view_config(route_name='home', renderer='home.html')
def static_view(request):
    return {}



"""Scaffold installation script.
"""
import os
import re
from setuptools import setup
from setuptools import find_packages

here = os.path.abspath(os.path.dirname(__file__))
README = open(os.path.join(here, 'README.rst')).read()
CHANGES = open(os.path.join(here, 'CHANGES.rst')).read()
version = '1.1'

setup(name='pyramid_lxneng',
      version=version,
      description='pyramid_lxneng pyramid scaffold',
      long_description=README + '\n\n' + CHANGES,
      author='Eric Lo',
      author_email='lxneng@gmail.com',
      url='http://lxneng.com',
      packages=find_packages('src'),
      package_dir={'': 'src'},
      install_requires=['pyramid'],
      include_package_data=True,
      zip_safe=False,
      entry_points="""\
      [pyramid.scaffold]
      lxneng = pyramid_lxneng.scaffolds:LxnengProjectTemplate
      """,
      )
